@@ -179,11 +179,11 @@ next_block:
 			/* Run-length encoded codeword lengths */
 
 			/*
-			 * Note: we don't need verify that the repeat count
-			 * doesn't overflow the number of elements, since we've
-			 * sized the lens array to have enough extra space to
-			 * allow for the worst-case overrun (138 zeroes when
-			 * only 1 length was remaining).
+			 * Note: we don't need to immediately verify that the
+			 * repeat count doesn't overflow the number of elements,
+			 * since we've sized the lens array to have enough extra
+			 * space to allow for the worst-case overrun (138 zeroes
+			 * when only 1 length was remaining).
 			 *
 			 * In the case of the small repeat counts (presyms 16
 			 * and 17), it is fastest to always write the maximum
@@ -241,6 +241,9 @@ next_block:
 			}
 		} while (i < num_litlen_syms + num_offset_syms);
 
+		/* Unnecessary, but check this for consistency with zlib. */
+		SAFETY_CHECK(i == num_litlen_syms + num_offset_syms);
+
 	} else if (block_type == DEFLATE_BLOCKTYPE_UNCOMPRESSED) {
 		u16 len, nlen;
 
